%bcond_with pacrunner

Summary:        A library handling all the details of proxy configuration
Name:           libproxy
Version:        0.4.18
Release:        4%{?dist}
License:        LGPLv2+
URL:            https://libproxy.github.io/libproxy/
Source0:        https://github.com/libproxy/%{name}/releases/download/%{name}-%{version}.tar.xz
BuildRequires:  cmake >= 2.6.0, gcc-c++
BuildRequires:  pkgconfig(gio-2.0) >= 2.26, pkgconfig(libnm), pkgconfig(dbus-1)
BuildRequires:  pkgconfig(javascriptcoregtk-4.0), python3-devel
Provides:       %{name}-bin

%description
libproxy offers the following features:

  * support for all major platforms: Windows, Mac and Linux/UNIX (see upcoming 0.4 release)
  * extremely small core footprint
  * no external dependencies within libproxy core (libproxy plugins may have dependencies)
  * only 3 functions in the stable-ish external API (1.0 will offer full stability)
  * dynamic adjustment to changing network topology
  * a standard way of dealing with proxy settings across all scenarios
  * a sublime sense of joy and accomplishment

%package -n     python3-%{name}
Summary:        Binding for %{name} and python3
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description -n python3-%{name}
The python3 binding for %{name}

%package        gnome
Summary:        Plugin for %{name} and gnome
Requires:       %{name} = %{version}-%{release}

%description    gnome
This package provides the gnome plugin.

%package        networkmanager
Summary:        Plugin for %{name} and networkmanager
Requires:       %{name} = %{version}-%{release}

%description    networkmanager
This package contains the networkmanager plugin.

%if %{with pacrunner}
%package        pacrunner
Summary:        Plugin for %{name} and PacRunner
Requires:       %{name} = %{version}-%{release}
Provides:       %{name}-pac = %{version}-%{release}
Requires:       pacrunner

%description    pacrunner
This package provides the PacRunner plugin.
%endif

%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}

%description    devel
This package provides libraries and header files for
developers who use %{name}.

%prep
%autosetup -p1

%build
export CXXFLAGS="-std=c++14 $RPM_OPT_FLAGS"
%{cmake} \
  -DMODULE_INSTALL_DIR=%{_libdir}/%{name}/%{version}/modules \
  -DBIPR=OFF \
  -DWITH_KDE=OFF \
  -DWITH_MOZJS=OFF \
  -DWITH_PERL=OFF \
  -DWITH_GNOME3=ON \
  -DWITH_PYTHON2=OFF \
  -DWITH_PYTHON3=ON \
  -DWITH_WEBKIT3=OFF

%cmake_build


%install
%cmake_install


%check
%ctest

%if %{without pacrunner}
rm -rf %{buildroot}/%{_libdir}/%{name}/%{version}/modules/config_pacrunner.so
rm -rf %{buildroot}/usr/lib/debug/%{_libdir}/%{name}/%{version}/modules/config_pacrunner.so*
%endif

%files
%license COPYING
%doc AUTHORS README
%{_bindir}/proxy
%{_libdir}/*.so.*
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/%{version}
%dir %{_libdir}/%{name}/%{version}/modules

%files -n python3-%{name}
%{python3_sitelib}/__pycache__/*
%{python3_sitelib}/%{name}.*

%files gnome
%{_libexecdir}/pxgsettings
%{_libdir}/%{name}/%{version}/modules/config_gnome3.so

%files networkmanager
%{_libdir}/%{name}/%{version}/modules/network_networkmanager.so

%if %{with pacrunner}
%files pacrunner
%{_libdir}/%{name}/%{version}/modules/config_pacrunner.so
%endif

%files devel
%{_libdir}/*.so
%{_libdir}/pkgconfig/libproxy-1.0.pc
%{_includedir}/proxy.h
%{_datadir}/cmake/Modules/Findlibproxy.cmake


%changelog
* Mon Jul 24 2023 Xiaojie Chen <jackxjchen@tencent.com> - 0.4.18-4
- Rebuilt for webkitgtk 2.41.6

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.4.18-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.4.18-2
- Rebuilt for OpenCloudOS Stream 23

* Wed Jul 13 2022 cunshunxia <cunshunxia@tencent.com> - 0.4.18-1
- initial build
